@@ -20,6 +20,16 @@ def zfile(file):
     return file
 
 
+# gets query from a .sql file
+def get_query_from_file(file_name):
+    pt(f'Retrieving Query from <{file_name}>')
+    q = open(zfile(file_name), 'r', encoding='utf-8-sig')
+    query = q.read()
+    print_query = query.replace("\n", " ").strip()
+    pt(f'Query Preview: <{print_query if len(print_query) < 50 else print_query[:50] + "..."}>')
+    return query
+
+
 # function to get data from sql
 def sql_get_data(query=None, file=None, server='AAO-LI-AHCRP002.Thehutgroup.LOCAL', username=None, password=None):
     '''
@@ -43,15 +53,13 @@ def sql_get_data(query=None, file=None, server='AAO-LI-AHCRP002.Thehutgroup.LOCA
 
     # print statements for query configurations & contents
     def print_query_statement(server, username, query, file=None):
-        if len(query) > 50:
-            query = query[:50] + '...'
-
         pt(f'Executing SQL Query')
         pt(f'SQL Server: {server}', indent=True)
         pt(f'SQL Username: {username if username is not None else "<Windows Authentication>"}', indent=True)
         if file != None:
             pt(f'Query File: {file}', indent=True)
-        pt(f'Query Preview: <{query}>', indent=True)
+        print_query = query.replace("\n", " ").strip()
+        pt(f'Query Preview: <{print_query if len(print_query) < 50 else print_query[:50] + "..."}>', indent=True)
 
     # extract query from file (if applicable)
     if file != None:
@@ -136,9 +144,10 @@ def sql_exec_statement(statement=None, file=None, server='AAO-LI-AHCRP002.Thehut
         pt(f'SQL Username: {username if username is not None else "<Windows Authentication>"}', indent=True)
         if file != None:
             pt(f'File: {file}', indent=True)
-        pt(f'Statement: <{statement}>', indent=True)
+        print_statement = statement.replace("\n", " ").strip()
+        pt(f'Statement: <{print_statement if len(print_statement) < 50  else print_statement[:50]+"..."}>', indent=True)
 
-    # run sproc
+    # run statement
     print_query_statement(server, username, statement, file)
     starting_timestamp = datetime.datetime.now()
     connection = pymssql.connect(server=server, user=username, password=password)
@@ -154,7 +163,7 @@ def sql_exec_statement(statement=None, file=None, server='AAO-LI-AHCRP002.Thehut
 
 # function to upload a pandas dataframe to SQL server
 def sql_insert_df(df, column_types, table, server='AAO-LI-AHCRP002.Thehutgroup.LOCAL', username=None, password=None,
-                  chunksize=999, print_insert_statement=False):
+                  chunksize=999, print_insert_statement=False, print_rows_inserted=False):
     """
     :param df: <pandas.dataframe> dataframe to upload
     :param column_types: <dict> dictionary of column names and data type
@@ -164,6 +173,7 @@ def sql_insert_df(df, column_types, table, server='AAO-LI-AHCRP002.Thehutgroup.L
     :param password: <str> SQL password, defaults to windows authentication
     :param chunksize: <int> number of rows to insert at once, defaults to 999
     :param print_insert_statement: <bool> prints each insert statement, useful for troubleshooting, defaults to False
+    :param print_rows_inserted: <bool> prints no. of rows inserted per chunk, useful for troubleshooting, defaults to False
 
     Example:
     sql_insert_df(df=pd.DataFrame({'site': 'Myprotein',
@@ -235,13 +245,16 @@ def sql_insert_df(df, column_types, table, server='AAO-LI-AHCRP002.Thehutgroup.L
             cursor.execute(insert_string)
             connection.commit()
             insert_string = ''
-            pt(f'Inserted up to row {row_number}')
+            if print_rows_inserted:
+                pt(f'Inserted up to row {row_number}')
         row_number += 1
     if insert_string != '':
         cursor.execute(insert_string)
         connection.commit()
-        pt(f'Inserted up to row {len(df)}')
+        if print_rows_inserted:
+            pt(f'Inserted up to row {len(df)}')
 
     # print complete
     pt('Dataframe upload complete')
     pt(f'Runtime: {datetime.datetime.now() - starting_timestamp}', indent=True)
+
